@@ -2,4 +2,7 @@ from .bubble_sort import bubble_sort
 from .insertion_sort import insertion_sort
 from .selection_sort import selection_sort
 from .quick_sort import quick_sort
-from .merge_sort import merge_sort
\ No newline at end of file
+from .merge_sort import merge_sort
+from .heap_sort import heap_sort
+from .counting_sort import counting_sort
+from .radix_sort import radix_sort
\ No newline at end of file
